<script setup>
import { ref, nextTick, reactive, watch } from 'vue';
import { get, post, postBlob, postForm } from '@/utils/request.js'
import { formatMessage } from '@/utils/localeUtils.js';
import { message } from 'ant-design-vue';
import {
    MinusCircleOutlined,
    PlusOutlined,
} from "@ant-design/icons-vue";

const formTable = ref(null);
const submitButton = ref(null);
const isSave = ref(true);
const open = ref(false);
const initFormData = {}
let formData = ref(initFormData);

const dynamicValidateForm = reactive({
    detls: [],
});

const emit = defineEmits(['tableReload'])

const handleOk = (e) => {
    nextTick(() => {
        setTimeout(() => {
            submitButton.value.$el.click();
        }, 100);
    });
};

const onFinish = values => {
    // console.log('Success:', values);
    open.value = false;

    let detls = []
    dynamicValidateForm.detls.forEach((item) => {
        detls.push(item.value)
    })
    formData.value.detls = detls;
    post(isSave.value ? '/api/shelvesRule/save' : '/api/shelvesRule/update', formData.value).then((resp) => {
        let result = resp.data;
        if (result.code === 200) {
            message.success(isSave.value ? formatMessage('page.add.success', '新增成功') : formatMessage('page.update.success', '更新成功'));
        } else {
            message.error(result.msg);
        }
        emit('tableReload', 'reload')
        nextTick(() => {
            formTable.value.resetFields()
        })
    })
};
const onFinishFailed = errorInfo => {
    console.log('Failed:', errorInfo);
};

const userQueryList = ref(null);
userQuery();
function userQuery() {
    postForm('/api/user/query', {}).then(resp => {
        let result = resp.data;
        userQueryList.value = result.data;
    })
}

const lanewayRuleQueryList = ref(null);
lanewayRuleQuery();
function lanewayRuleQuery() {
    postForm('/api/lanewayRule/query', {}).then(resp => {
        let result = resp.data;
        lanewayRuleQueryList.value = result.data;
    })
}

const removeDomain = item => {
    const index = dynamicValidateForm.detls.indexOf(item);
    if (index !== -1) {
        dynamicValidateForm.detls.splice(index, 1);
    }
};

const addDomain = () => {
    dynamicValidateForm.detls.push({
        value: '',
    });
};

watch(open, (newVal, oldVal) => {
    if (open.value) {
        if (!isSave.value) {
            let ruleDetls = formData.value.ruleDetl$
            let detls = []
            ruleDetls.forEach((item) => {
                detls.push({
                    value: item.detlType
                })
            })

            dynamicValidateForm.detls = detls;
        }
    }else {
        dynamicValidateForm.detls = []
    }
})

defineExpose({
    open,
    formData,
    initFormData,
    isSave,
})

</script>

<script>
export default {
    name: '上架规则-edit'
}
</script>

<template>
    <div>
        <a-modal v-model:open="open"
            :title="isSave ? formatMessage('page.add', '添加') : formatMessage('page.edit', '编辑')" @ok="handleOk"
            style="width: 600px;">
            <a-form :model="formData" ref="formTable" name="formTable" :label-col="{ span: 8 }"
                :wrapper-col="{ span: 16 }" style="display: flex;justify-content: space-between;flex-wrap: wrap;"
                autocomplete="off" @finish="onFinish" @finishFailed="onFinishFailed">
                <a-form-item :label="formatMessage('db.strategy_shelves_rule.name', '规则名称')" name="name"
                    style="width: 250px;">
                    <a-input v-model:value="formData.name" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.strategy_shelves_rule.rule_type', '规则类型')" name="ruleType"
                    style="width: 250px;">
                    <a-select v-model:value="formData.ruleType" :options="[
                        { label: '优先平层', value: 0 },
                        { label: '优先立体', value: 1 },
                    ]">
                    </a-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.strategy_shelves_rule.lane', '巷道')" name="lane"
                    style="width: 250px;">
                    <a-select v-model:value="formData.laneList" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search mode="multiple" :options="lanewayRuleQueryList"
                        optionFilterProp="label" optionLabelProp="label">
                    </a-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.strategy_shelves_rule.status', '状态')" name="status"
                    style="width: 250px;">
                    <a-select v-model:value="formData.status" :options="[
                        { label: '正常', value: 1 },
                        { label: '禁用', value: 0 },
                    ]">
                    </a-select>
                </a-form-item>
                <!-- <a-form-item :label="formatMessage('db.strategy_shelves_rule.create_time', '添加时间')" name="createTime"
                    style="width: 250px;">
                    <a-date-picker v-model:value="formData.createTime" show-time format="YYYY-MM-DD HH:mm:ss"
                        value-format="YYYY-MM-DD HH:mm:ss" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.strategy_shelves_rule.create_by', '添加人员')" name="createBy"
                    style="width: 250px;">
                    <a-select v-model:value="formData.createBy" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="userQueryList" optionFilterProp="label"
                        optionLabelProp="label">
                    </a-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.strategy_shelves_rule.update_time', '修改时间')" name="updateTime"
                    style="width: 250px;">
                    <a-date-picker v-model:value="formData.updateTime" show-time format="YYYY-MM-DD HH:mm:ss"
                        value-format="YYYY-MM-DD HH:mm:ss" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.strategy_shelves_rule.update_by', '修改人员')" name="updateBy"
                    style="width: 250px;">
                    <a-select v-model:value="formData.updateBy" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="userQueryList" optionFilterProp="label"
                        optionLabelProp="label">
                    </a-select>
                </a-form-item> -->
                <a-form-item :label="formatMessage('db.strategy_shelves_rule.memo', '备注')" name="memo"
                    style="width: 250px;">
                    <a-input v-model:value="formData.memo" />
                </a-form-item>

                <a-form-item>
                    <a-button type="primary" html-type="submit" ref="submitButton"
                        style="visibility: hidden;">Submit</a-button>
                </a-form-item>
            </a-form>

            <a-form>
                <a-form-item v-for="(domain, index) in dynamicValidateForm.detls" :key="domain.key"
                    :label="formatMessage('db.strategy_shelves_rule.memo', '规则明细')" :name="['domains', index, 'value']"
                    :labelCol="{ span: 4, offset: 1 }" style="width: 100%;">
                    <div style="width: 400px;">
                        <a-select v-model:value="domain.value" :options="[
                            { label: '库存或任务中匹配相邻库位', value: 1 },
                            { label: '推荐区域', value: 2 },
                            { label: '完整巷道', value: 3 },
                        ]" style="width: 300px;margin-right: 20px;">
                        </a-select>
                        <MinusCircleOutlined v-if="dynamicValidateForm.detls.length > 1"
                            @click="removeDomain(domain)" />
                    </div>
                </a-form-item>
                <a-form-item :labelCol="{ span: 4, offset: 1 }" style="width: 100%;">
                    <div style="width: 200px;">
                        <a-button type="dashed" style="width: 200px;" @click="addDomain">
                            <PlusOutlined />
                            {{ formatMessage('db.strategy_shelves_rule.addDetl', '添加明细') }}
                        </a-button>
                    </div>
                </a-form-item>
            </a-form>
        </a-modal>
    </div>
</template>

<style></style>
